@@ -81,21 +81,27 @@ class API:
 
         try:
             self._wait_for_element(
-                tag='class name',
-                locator='rc-audiochallenge-error-message',
+                tag='xpath',
+                locator='//div[normalize-space()="Multiple correct solutions required - please solve more."]',
                 timeout=1,
             )
 
             self._solve_audio_challenge()
 
-            self._js_click(verify_button)
+            # Locate verify button again to avoid stale element reference and click it via JavaScript
+            second_verify_button = self._wait_for_element(
+                tag='id',
+                locator='recaptcha-verify-button',
+                timeout=5,
+            )
+
+            self._js_click(second_verify_button)
 
         except TimeoutException:
             pass
 
-        finally:
-            # Switch back to driver's default content
-            self.__driver.switch_to.default_content()
+        # Switch back to driver's default content
+        self.__driver.switch_to.default_content()
 
     def _solve_audio_challenge(self) -> None:
         try:
@@ -128,17 +134,21 @@ class API:
         # Convert mp3 to wav format for compatibility with Google's speech recognition API
         AudioSegment.from_mp3(mp3_file).export(wav_file, format='wav')
 
-        # Disable dynamic energy thershold to avoid failed Captcha audio transcription due to static noise
+        # Disable dynamic energy threshold to avoid failed Captcha audio transcription due to static noise
         self.__recognizer.dynamic_energy_threshold = False
 
+        self.__recognizer.energy_threshold = 400
+
         with sr.AudioFile(wav_file) as source:
+            self.__recognizer.adjust_for_ambient_noise(source, duration=1)
+
             audio = self.__recognizer.listen(source)
 
             try:
                 recognized_text = self.__recognizer.recognize_google(audio, key=self.__google_api_key)
 
             except sr.UnknownValueError:
-                raise RecaptchaException('Failed to automatically solve Captcha, try again.')
+                raise RecaptchaException('Speech recognition API could not understand audio, try again.')
 
         # Clean up all temporary files
         self._cleanup(tmp_files)
